using System.Collections.Generic;

namespace Encompass
{
    public class World
    {
        private List<Engine> enginesInOrder;
        private EntityManager entityManager;
        private ComponentManager componentManager;
        private MessageManager messageManager;
        private RenderManager renderManager;

        internal World(
            List<Engine> enginesInOrder,
            EntityManager entityManager,
            ComponentManager componentManager,
            MessageManager messageManager,
            RenderManager renderManager
        )
        {
            this.enginesInOrder = enginesInOrder;
            this.entityManager = entityManager;
            this.componentManager = componentManager;
            this.messageManager = messageManager;
            this.renderManager = renderManager;
        }

        public void Update(float dt)
        {
            foreach (var engine in enginesInOrder)
            {
                engine.Update(dt);
            }

            messageManager.ClearMessages();
            entityManager.DestroyMarkedEntities();

            componentManager.ActivateMarkedComponents();
            componentManager.DeactivateMarkedComponents();
            componentManager.RemoveMarkedComponents();

            entityManager.CheckEntitiesWithAddedComponents();
            entityManager.CheckEntitiesWithRemovedComponents();
        }

        public void Draw()
        {
            renderManager.Draw();
        }
    }
}
